16.27. cdist-type__consul_watch_event(7) — cdist 4.11.0 documentation

# 16.27. cdist-type__consul_watch_event(7)

## 16.27.1. NAME

cdist-type__consul_watch_event - Manages consul event watches

## 16.27.2. DESCRIPTION

Generate and deploy watch definitions of type 'event' for a consul agent. See http://www.consul.io/docs/agent/watches.html for parameter documentation.

## 16.27.3. REQUIRED PARAMETERS

handler
  the handler to invoke when the data view updates

## 16.27.4. OPTIONAL PARAMETERS

datacenter
  can be provided to override the agent's default datacenter
name
  restrict the watch to only events with the given name
state
  if this watch is 'present' or 'absent'. Defaults to 'present'.
token
  can be provided to override the agent's default ACL token

## 16.27.5. EXAMPLES

    __consul_watch_event some-id \
       --handler /usr/bin/my-handler.sh

    __consul_watch_event some-id \
       --name web-deploy \
       --handler /usr/bin/my-handler.sh

## 16.27.6. SEE ALSO

cdist-type__consul_agent(7)

consul documentation at: <http://www.consul.io/docs/agent/watches.html>.

## 16.27.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.27.8. COPYING

Copyright (C) 2015 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.